@@ -1,6 +1,8 @@
 def add_two_numbers(num1, num2):
+    "add two numbers"
     return num1 + num2
 
 def subtract_two_numbers(num1, num2):
+    "subtract_two_numbers two numbers"
     return num1 - num2
 
